/*
 * Copyright (c) 2024 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 */

#include <zephyr/kernel.h>
#include <zephyr/logging/log.h>
#include <dk_buttons_and_leds.h>
#include <zephyr/drivers/rtc.h>

LOG_MODULE_REGISTER(Lesson2_Exercise3, LOG_LEVEL_DBG);

static const struct device *rtc = DEVICE_DT_GET(DT_ALIAS(rtc));

static void rtc_work_handler(struct k_work *work)
{
    struct rtc_time dt;

    rtc_get_time(rtc, &dt);
    LOG_DBG("%04d/%02d/%02d %02d:%02d:%02d\n",
            dt.tm_year, dt.tm_mon, dt.tm_mday,
            dt.tm_hour, dt.tm_min, dt.tm_sec);
}

K_WORK_DEFINE(rtc_work, rtc_work_handler);

void button_handler(uint32_t button_state, uint32_t has_changed)
{
#if 0
	k_work_submit(&rtc_work);
#else
	struct rtc_time dt;
    int ret = rtc_get_time(rtc, &dt);

    LOG_DBG("get time: %d\n", ret);
    LOG_DBG("%04d/%02d/%02d %02d:%02d:%02d\n",
            dt.tm_year, dt.tm_mon, dt.tm_mday,
            dt.tm_hour, dt.tm_min, dt.tm_sec);
#endif

	if (has_changed & button_state)
	{
		switch (has_changed)
		{
            case DK_BTN1_MSK:
                LOG_INF("Button 1 pressed");
                break;
			default:
				break;
		}
    }
}

int main(void)
{
    struct rtc_time dt = {
        .tm_sec = 0,
        .tm_min = 25,
        .tm_hour = 15,
        .tm_yday = 19,
        .tm_mon = 9,
        .tm_year = 2024,
    };

    rtc_set_time(rtc, &dt);

    int ret = rtc_get_time(rtc, &dt);
    LOG_DBG("get time: %d\n", ret);
    LOG_DBG("%04d/%02d/%02d %02d:%02d:%02d\n",
            dt.tm_year, dt.tm_mon, dt.tm_mday,
            dt.tm_hour, dt.tm_min, dt.tm_sec);

    if (dk_buttons_init(button_handler)) {
        LOG_ERR("Failed to initialize the buttons library");
    }

	LOG_INF("Press button 1");

	return 0;
}